@@ -1,29 +1,6 @@
-# RDF::Trine::Parser::ShorthandRDF
-# -----------------------------------------------------------------------------
-
-=head1 NAME
-
-RDF::Trine::Parser::ShorthandRDF - Shorthand RDF Parser
-
-=head1 SYNOPSIS
-
- use RDF::Trine::Parser;
- my $parser     = RDF::Trine::Parser->new( 'ShorthandRDF' );
- $parser->parse_into_model( $base_uri, $data, $model );
-
-=head1 DESCRIPTION
-
-ShorthandRDF is an extension of N3 syntax. It's currently defined at
-L<http://esw.w3.org/ShorthandRDF>.
-
-=head1 METHODS
-
-This package exposes the same methods as RDF::Trine::Parser::Notation3.
-
-=cut
-
 package RDF::Trine::Parser::ShorthandRDF;
 
+use utf8;
 use 5.010;
 use strict;
 use warnings;
@@ -41,7 +18,7 @@ our ($VERSION, $AUTHORITY);
 
 BEGIN 
 {
-	$VERSION   = '0.136';
+	$VERSION   = '0.204';
 	$AUTHORITY = 'cpan:TOBYINK';
 	
 	my $class = __PACKAGE__;
@@ -49,7 +26,7 @@ BEGIN
 	$RDF::Trine::Parser::canonical_media_types{ $class } = 'text/x.shorthand-rdf';
 	
 	$RDF::Trine::Parser::parser_names{$_} = __PACKAGE__
-		foreach ('shorthand', 'shorthandrdf', 'shorthand-rdf', 'shorthand rdf');
+		foreach ('shorthand', 'shorthandrdf');
 	
 	$RDF::Trine::Parser::media_types{$_} = __PACKAGE__
 		foreach qw(text/x.shorthand-rdf text/x-shorthand-rdf);
@@ -67,15 +44,88 @@ sub _Document {
 	my $uri  = $self->{'baseURI'};
 	$self->{bindings}     = {};
 	$self->{bindings}{''} = ($uri =~ /#$/ ? $uri : "${uri}#");
-	$self->{'keywords'}   = undef;
-	$self->{'shorthands'} = [];
-	$self->_apply_profile($self->{'baseURI'}, $self->{'profile'}, 0) if defined $self->{'profile'};
+	$self->{keywords}     = undef;
+	$self->{shorthands}   = [];
+	$self->{pragmata}     = {};
+	$self->_apply_profile($self->{baseURI}, $self->{profile}, 0)
+		if defined $self->{profile} && length $self->{profile};
 	$self->SUPER::_Document(@_);
 }
 
+sub _triple {
+	my ($self, $s, $p, $o) = @_;
+	
+	if (defined $self->{pragmata}{rdf}
+	and $self->{pragmata}{rdf}->is_literal
+	and lc $self->{pragmata}{rdf}->literal_value eq 'true')
+	{
+		my $st = RDF::Trine::Statement->new($s, $p, $o);
+		throw RDF::Trine::Error::ParserError -text => ("Non-RDF triple in RDF-only mode: ".$st->sse)
+			unless $st->rdf_compatible && !$o->isa('RDF::Trine::Node::Formula');
+	}
+
+	if (defined $self->{pragmata}{'blank-nodes'}
+	and $self->{pragmata}{'blank-nodes'}->is_literal
+	and lc $self->{pragmata}{'blank-nodes'}->literal_value eq 'false')
+	{
+		my $st = RDF::Trine::Statement->new($s, $p, $o);
+		throw RDF::Trine::Error::ParserError -text => ("Blank node found: ".$st->sse)
+			if grep { $_->is_blank } ($s, $p, $o);
+	}
+
+	if (defined $self->{pragmata}{trig}
+	and $self->{pragmata}{trig}->is_literal
+	and lc $self->{pragmata}{trig}->literal_value eq 'true'
+	and $s->is_resource
+	and $p->is_resource
+	and $p->uri eq 'http://www.w3.org/2002/07/owl#sameAs'
+	and $o->isa('RDF::Trine::Node::Formula')
+	and (my $code = $self->{handle_triple}))
+	{
+		foreach my $st ($o->pattern->triples)
+		{
+			my ($S, $P, $O) = $st->nodes;
+			
+			if ($self->{canonicalize}
+			and $O->isa('RDF::Trine::Node::Literal')
+			and $O->has_datatype)
+			{
+				my $canon = RDF::Trine::Node::Literal->canonicalize_literal_value(
+					$O->literal_value, $O->literal_datatype, 1);
+				$O = RDF::Trine::Node::Literal->new($canon, undef, $O->literal_datatype);
+			}
+			
+			my $quad = RDF::Trine::Statement::Quad->new($S, $P, $O, $s);
+			$code->($quad);
+		}
+		
+		return;
+	}
+	
+	$self->SUPER::_triple($s, $p, $o);
+}
+
+sub __consume_ws {
+	my $self	= shift;
+	BIT: while ($self->{tokens} =~ m/^[\t\r\n #]/)
+	{
+		if ($self->{tokens} =~ m/^[#]/)
+		{
+			foreach my $shorthand ( reverse @{ $self->{shorthands} } )
+			{
+				my ($type, $pattern, $full, $basethen) = @$shorthand;
+				last BIT if ($type eq '@pattern' and $self->{tokens} =~ $pattern);
+			}
+		}
+		
+		$self->_ws();
+	}
+}
+
+
 sub _directive_test {
 	my $self	= shift;
-	if ($self->{'tokens'} =~ m/^\@(base|prefix|forSome|forAll|keywords|namepattern|dtpattern|pattern|term|profile|import)\b/io) {
+	if ($self->{tokens} =~ m/^\@(base|prefix|forSome|forAll|keywords|namepattern|dtpattern|pattern|term|profile|import|pragma)\b/io) {
 		return 1;
 	} else {
 		return 0;
@@ -85,7 +135,9 @@ sub _directive_test {
 # Shorthand-specific directives
 sub _directive {
 	my $self	= shift;
-	if ($self->_at_namepattern_test()) {
+	if ($self->_at_pragma_test()) {
+		$self->_at_pragma();
+	} elsif ($self->_at_namepattern_test()) {
 		$self->_at_namepattern();
 	} elsif ($self->_at_dtpattern_test()) {
 		$self->_at_dtpattern();
@@ -115,6 +167,11 @@ sub _at_term_test {
 	return $self->__startswith('@term');
 }
 
+sub _at_pragma_test {
+	my $self = shift;
+	return $self->__startswith('@pragma');
+}
+
 sub _at_pattern_test {
 	my $self = shift;
 	return $self->__startswith('@pattern');
@@ -138,7 +195,7 @@ sub _at_namepattern {
 	my $uri = $self->_uriref();
 	$self->__consume_ws();
 
-	push @{ $self->{shorthands} }, ['@pattern', $pattern, RDF::Trine::Node::Resource->new($uri.'$0'), $self->{baseURI}];
+	push @{ $self->{shorthands} }, ['@pattern', qr/^($pattern)/, RDF::Trine::Node::Resource->new($uri.'$0'), $self->{baseURI}];
 	return $self->{shorthands}[-1];
 }
 
@@ -153,13 +210,14 @@ sub _at_pattern {
 	$self->__consume_ws();
 	
 	my $thing;
+	local($self->{suspend_callback}) = 1;
 	if ($self->_resource_test)
 		{ $thing = $self->_resource(); }
 	else
 		{ $thing = $self->_literal(); }
 	$self->__consume_ws();
 
-	push @{ $self->{shorthands} }, ['@pattern', $pattern, $thing, $self->{baseURI}];
+	push @{ $self->{shorthands} }, ['@pattern', qr/^($pattern)/, $thing, $self->{baseURI}];
 	return $self->{shorthands}[-1];
 }
 
@@ -176,7 +234,7 @@ sub _at_dtpattern {
 	my $uri = $self->_uriref();
 	$self->__consume_ws();
 
-	push @{ $self->{shorthands} }, ['@pattern', $pattern, RDF::Trine::Node::Literal->new('$0', undef, $uri), $self->{baseURI}];
+	push @{ $self->{shorthands} }, ['@pattern', qr/^($pattern)/, RDF::Trine::Node::Literal->new('$0', undef, $uri), $self->{baseURI}];
 	return $self->{shorthands}[-1];
 }
 
@@ -200,6 +258,7 @@ sub _at_term {
 	}
 	$self->__consume_ws();
 
+	local($self->{suspend_callback}) = 1;
 	my $thing = $self->_any_node();
 	$self->__consume_ws();
 
@@ -207,6 +266,33 @@ sub _at_term {
 	return $self->{shorthands}[-1];
 }
 
+sub _at_pragma {
+	my $self	= shift;
+	
+	$self->_eat('@pragma');
+	$self->_ws();
+	$self->__consume_ws();
+	
+	my $token;
+	
+	if ( $self->{'tokens'} =~ m/^([A-Za-z_][A-Za-z0-9_-]*)\s/o )
+	{
+		$token = $1;
+		$self->_eat($token);
+	}
+	else
+	{
+		$self->_eat('token_name'); # and die!
+	}
+	$self->__consume_ws();
+
+	local($self->{suspend_callback}) = 1;
+	my $value = $self->_any_node();
+	$self->__consume_ws();
+
+	return $self->{pragmata}{$token} = $value;
+}
+
 sub _at_profile {
 	my $self	= shift;
 	
@@ -231,7 +317,7 @@ sub _at_profile {
 		)) if $import;
 
 	my $ua = LWP::UserAgent->new(agent => "RDF::TriN3/$RDF::TriN3::VERSION");
-	$ua->default_headers->push_header(Accept => 'text/x-shorthand-rdf, text/n3, text/turtle');
+	$ua->default_headers->push_header(Accept => 'text/x.shorthand-rdf, text/x-shorthand-rdf, text/n3, text/turtle');
 	my $resp = $ua->get($url);
 	unless ($resp->is_success) {
 		throw RDF::Trine::Error::ParserError -text => $resp->status_line;
@@ -245,10 +331,10 @@ sub _apply_profile
 	my ($self, $base, $data, $import) = @_;
 	
 	my $class = ref $self;
-	my $child = $class->new;
+	my $child = $class->new(profile => '');
 	$child->parse($base, $data, sub {
 		$self->{handle_triple}->($_[0]) if $import;
-		});
+	});
 		
 	my %child_bindings = %{ $child->{bindings} || {} };
 	while (my ($prefix, $full) = each %child_bindings)
@@ -272,16 +358,10 @@ sub _resource_test {
 	{
 		my ($type, $pattern, $full, $basethen) = @$shorthand;
 		
-		if ($type eq '@pattern'
-		and $self->{'tokens'} =~ m/^($pattern)\b/)
-		{
-			return 1;
-		}
-		elsif ($type eq '@term'
-		and (substr $self->{'tokens'}, 0, (length $pattern)) eq $pattern)
-		{
-			return 1;
-		}
+		if ($type eq '@pattern' and $self->{'tokens'} =~ $pattern)
+			{ return 1; }
+		elsif ($type eq '@term' and $self->__startswith($pattern))
+			{ return 1; }
 	}	
 
 	return 0;
@@ -289,13 +369,12 @@ sub _resource_test {
 
 sub _resource {
 	my $self	= shift;
-	
+
 	foreach my $shorthand ( reverse @{ $self->{shorthands} } )
 	{
 		my ($type, $pattern, $full, $basethen) = @$shorthand;
 		
-		if ($type eq '@pattern'
-		and $self->{'tokens'} =~ m/^($pattern)\b/)
+		if ($type eq '@pattern' and $self->{'tokens'} =~ $pattern)
 		{
 			my $token = $1;
 			$self->_eat($token);
@@ -304,7 +383,7 @@ sub _resource {
 			{
 				my $replaced_uri = $self->_PATTERN_($token, $pattern, $full->literal_datatype);
 				my $absolute_uri = $self->__URI($replaced_uri, $basethen);
-				return RDF::Trine::Node::Literal->new(
+				return $self->__Literal(
 					$self->_PATTERN_($token, $pattern, $full->literal_value),
 					undef,
 					$absolute_uri,
@@ -312,7 +391,7 @@ sub _resource {
 			}
 			elsif ($full->is_literal)
 			{
-				return RDF::Trine::Node::Literal->new(
+				return $self->__Literal(
 					$self->_PATTERN_($token, $pattern, $full->literal_value),
 					($full->has_language ? $self->_PATTERN_($token, $pattern, $full->literal_value_language) : undef),
 					);
@@ -323,8 +402,7 @@ sub _resource {
 				return $self->__URI($replaced_uri, $basethen);
 			}
 		}
-		elsif ($type eq '@term'
-		and (substr $self->{'tokens'}, 0, (length $pattern)) eq $pattern)
+		elsif ($type eq '@term' and $self->__startswith($pattern))
 		{
 			$self->_eat($pattern);
 			return $full;
@@ -402,9 +480,34 @@ sub _PATTERN_
 
 __END__
 
+=head1 NAME
+
+RDF::Trine::Parser::ShorthandRDF - Shorthand RDF Parser
+
+=head1 SYNOPSIS
+
+ use RDF::Trine::Parser;
+ my $parser     = RDF::Trine::Parser->new( 'ShorthandRDF' );
+ $parser->parse_into_model( $base_uri, $data, $model );
+
+=head1 DESCRIPTION
+
+ShorthandRDF is an extension of N3 syntax. It's currently defined at
+L<http://esw.w3.org/ShorthandRDF>.
+
+=head2 Methods
+
+This package exposes the same methods as RDF::Trine::Parser::Notation3.
+
+=head1 BUGS
+
+Please report any bugs to
+L<http://rt.cpan.org/Dist/Display.html?Queue=RDF-TriN3>.
+
 =head1 SEE ALSO
 
 L<RDF::TriN3>,
+L<RDF::Trine::Parser::Pretdsl>,
 L<RDF::Trine::Parser::Notation3>.
 
 L<http://esw.w3.org/ShorthandRDF>.
@@ -419,7 +522,7 @@ Based on RDF::Trine::Parser::Turtle by Gregory Todd Williams.
 
 Copyright (c) 2006-2010 Gregory Todd Williams. 
 
-Copyright (c) 2010-2011 Toby Inkster.
+Copyright (c) 2010-2012 Toby Inkster.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
